==> owncloud-10.2.0.zip: owncloud/apps/federatedfilesharing/l10n/pt_BR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartilhamento federado",
    "Invalid Federated Cloud ID" : "Inválida Associação de Nuvem ID",
    "Sharing %s failed, because this item is already shared with %s" : "Compartilhamento %s falhou, porque este ítem já está compartilhado com %s",
    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
    "File is already shared with %s" : "O arquivo já é compartilhado com %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "O compartilhamento %s falhou, porque não foi possível encontrar %s, talvez o servidor esteja inacessível.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Você recebeu \"/%3$s\" como um compartilhamento remoto de %1$s (em nome de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Você recebeu \"/%3$s\" como um compertilhamento remoto de %1$s",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Federada, veja %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Federada",
    "Federated Cloud Sharing" : "Nuvem Associada Federada",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários nesse servidor recebam compartilhamentos de outros servidores",
    "Federated Cloud" : "Nuvem Federada",
    "Your Federated Cloud ID:" : "Sua ID na Nuvem Federada:",
    "Share it:" : "Compartilhe:",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via ownCloud" : "Compartilhe comigo via ownCloud",
    "HTML Code:" : "Código HTML:",
    "Add to your ownCloud" : "Adiconar ao seu ownCloud",
    "Automatically accept remote shares from trusted servers" : "Aceitar automaticamente compartilhamentos remotos de servidores confiáveis"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.4.0.zip: owncloud/apps/federatedfilesharing/l10n/pt_BR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartilhamento federado",
    "Add to your ownCloud" : "Adiconar ao seu ownCloud",
    "Invalid Federated Cloud ID" : "Inválida Associação de Nuvem ID",
    "Sharing %s failed, because this item is already shared with %s" : "Compartilhamento %s falhou, porque este ítem já está compartilhado com %s",
    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
    "File is already shared with %s" : "O arquivo já é compartilhado com %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "O compartilhamento %s falhou, porque não foi possível encontrar %s, talvez o servidor esteja inacessível.",
    "Federated Sharing failed: %s" : "O compartilhamento federado falhou: %s",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" compartilhado \"%3$s\" com você (em nome de \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" compartilhado \"%3$s\" com você",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\"convidou você para ver \"%3$s\" (em nome de \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" convidou você para visualizar \"%3$s\"",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Federada, veja %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Federada",
    "Federated Cloud Sharing" : "Nuvem Associada Federada",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários nesse servidor recebam compartilhamentos de outros servidores",
    "Automatically accept remote shares from trusted servers" : "Aceitar automaticamente compartilhamentos remotos de servidores confiáveis",
    "Federated Cloud" : "Nuvem Federada",
    "Your Federated Cloud ID:" : "Sua ID na Nuvem Federada:",
    "Share it:" : "Compartilhe:",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via ownCloud" : "Compartilhe comigo via ownCloud",
    "HTML Code:" : "Código HTML:",
    "Nothing to configure." : "Nada para configurar."
},
"nplurals=2; plural=(n > 1);");
